@@ -13,7 +13,7 @@ def cf_get_credentails(**kwargs):
         password {str} -- password (default: None)
         hostname {str} -- in 'https://api.sys.domainname.com' format
         org {str} -- Pivotal Cloud org name
-        token_url {str} -- url for fetching access_token in 'https://login.sys.domaain.com/oauth/token' format
+        token_url {str} -- url for fetching access_token in 'https://login.sys.domain.com/oauth/token' format
         space {str} -- Pivotal Cloud space
 
     Returns:
@@ -50,57 +50,54 @@ def cf_get_credentails(**kwargs):
     return credentials
 
 
-def cf_get_auth_header(output_option='AUTH_HEADER', credentials_file_path=None):
+def cf_get_auth_header(output_option='AUTH_HEADER', **credentials):
     """Return OAuth2 Bearer Access token for Authorization header for Pivotal Cloud Foundary API calls.
 
     Keyword Arguments:
         output_option {str} -- output format of function (default: {'AUTH_HEADER'})
             other options include {'TOKEN','RESPONSE','JSON'}
-        credentials_file_path {str} -- file path of credentails.json (default: {None})
+
+        Following keyword arugments can be provided to update default credentials:
+        username {str} -- user id (default: None)
+        password {str} -- password (default: None)
+        hostname {str} -- in 'https://api.sys.domainname.com' format
+        org {str} -- Pivotal Cloud org name
+        token_url {str} -- url for fetching access_token in 'https://login.sys.domain.com/oauth/token' format
+        space {str} -- Pivotal Cloud space
 
     Returns:
         {str, requests.response, requests.response.json} -- AUTH_HEADER and TOKEN are str
     """
 
-    if not credentials_file_path:
-        logging.debug(
-            "credentials file not provided, using default env variable PIVOTAL_CREDENTIALS")
-        credentials_file_path = os.environ.get('PIVOTAL_CREDENTIALS')
-        if not credentials_file_path:
-            logging.error("Default credentials not set")
-            credentials_file_path = 'no-cred'
+    credentials = cf_get_credentails(**credentials)
 
-    if os.path.isfile(credentials_file_path):
-        with open(credentials_file_path) as file:
-            credentials = json.loads(file.read())
+    headers = {"Content-Type": "application/json",
+               "Accept": "application/json;charset=UTF-8",
+               "Authorization": "Basic Y2Y6"}
+    username = credentials.get('username')
+    password = credentials.get('password')
+    token_url = credentials.get('token_url')
 
-        headers = {"Content-Type": "application/json",
-                   "Accept": "application/json;charset=UTF-8",
-                   "Authorization": "Basic Y2Y6"}
-        username = credentials.get('username')
-        password = credentials.get('password')
-        token_url = credentials.get('token_url')
+    logging.info(f"signing in {token_url} as {username}")
+    token_url = f'{token_url}?grant_type=password&username={username}&password={password}&response_type=token'
+    response = requests.get(token_url, verify=False, headers=headers)
+    logging.debug(
+        f"response code: {response.status_code} from token request to {response.url}")
 
-        logging.info(f"signing in {token_url} as {username}")
-        token_url = f'{token_url}?grant_type=password&username={username}&password={password}&response_type=token'
-        response = requests.get(token_url, verify=False, headers=headers)
-        logging.debug(
-            f"response code: {response.status_code} from token request to {response.url}")
-
-        if response.status_code == 200:
-            if output_option == 'RESPONSE':
-                return response
-            elif output_option == 'JSON':
-                return response.json()
-            elif output_option == 'TOKEN':
-                return response.json().get('access_token')
-            else:
-                return f"bearer {response.json().get('access_token')}"
-
-        else:
-            logging.error(
-                f"access_token request unsuccessfull with status code {response.status_code}")
+    if response.status_code == 200:
+        if output_option == 'RESPONSE':
             return response
+        elif output_option == 'JSON':
+            return response.json()
+        elif output_option == 'TOKEN':
+            return response.json().get('access_token')
+        else:
+            return f"bearer {response.json().get('access_token')}"
+
+    else:
+        logging.error(
+            f"access_token request unsuccessfull with status code {response.status_code}")
+        return response
 
 
 def cf_list_resources(resource='apps', output_option='JSON', name=None, auth_header=None, **credentials):
@@ -124,11 +121,11 @@ def cf_list_resources(resource='apps', output_option='JSON', name=None, auth_hea
     """
 
     if not auth_header:
-        credentials = cf_get_credentails(**credentials)  # dependency
+        credentials = cf_get_credentails(**credentials)  
         auth_header = cf_get_auth_header(
-            output_option='AUTH_HEADER', **credentials)  # dependency
+            output_option='AUTH_HEADER', **credentials)
     else:
-        credentials = cf_get_credentails(**credentials)  # dependency
+        credentials = cf_get_credentails(**credentials)  
 
     host = credentials.get('host')
 
@@ -187,11 +184,11 @@ def cf_get(url, auth_header=None, output_option='JSON', **credentials):
     """
 
     if not auth_header:
-        credentials = cf_get_credentails(**credentials)  # dependency
+        credentials = cf_get_credentails(**credentials)  
         auth_header = cf_get_auth_header(
-            output_option='AUTH_HEADER', **credentials)  # dependency
+            output_option='AUTH_HEADER', **credentials)  
     else:
-        credentials = cf_get_credentails(**credentials)  # dependency
+        credentials = cf_get_credentails(**credentials)  
 
     host = credentials.get('host')
     headers = {"Content-Type": "application/json",
@@ -228,9 +225,9 @@ def cf_requests(method, url, auth_header=None, output_option='JSON', **kwargs):
 
     """
     if not auth_header:
-        credentials = cf_get_credentails()  # dependency
+        credentials = cf_get_credentails()  
         auth_header = cf_get_auth_header(
-            output_option='AUTH_HEADER', **credentials)  # dependency
+            output_option='AUTH_HEADER', **credentials)  
 
     headers = {"Content-Type": "application/json",
                "Accept": "application/json;charset=UTF-8",
@@ -262,9 +259,9 @@ def cf_download_package(app_name=None, url=None, auth_header=None, output_option
         {str, io.BytesIO} -- for downloaded ``ZIP`` and ``GZIP`` path as str is returen while IO returns io.BytesIO
     """
     if not auth_header:
-        credentials = cf_get_credentails()  # dependency
+        credentials = cf_get_credentails()  
         auth_header = cf_get_auth_header(
-            output_option='AUTH_HEADER', **credentials)  # dependency
+            output_option='AUTH_HEADER', **credentials)  
 
     if url:
         app_name = "my_app"
@@ -298,11 +295,11 @@ def cf_download_package(app_name=None, url=None, auth_header=None, output_option
             file_like.seek(0)
 
         elif output_option == 'GZIP':
-            file_like = f"{url.split('/')[-1]}.gzip"
+            file_like = f"{url.split('/')[-2]}.gzip"
             with open(file_like, 'wb') as file:
                 file.write(response.content)
         else:
-            file_like = f"{url.split('/')[-1]}.zip"
+            file_like = f"{url.split('/')[-2]}.zip"
             with open(file_like, 'wb') as file:
                 file.write(response.content)
 
@@ -327,9 +324,9 @@ def cf_create_task(app_name, command, task_name=None, auth_header=None):
         {requests.response} -- [description]
     """
     if not auth_header:
-        credentials = cf_get_credentails()  # dependency
+        credentials = cf_get_credentails()  
         auth_header = cf_get_auth_header(
-            output_option='AUTH_HEADER', **credentials)  # dependency
+            output_option='AUTH_HEADER', **credentials)  
 
     app = cf_list_resources(
         resource='apps', auth_header=auth_header, name=app_name)
